@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "0.6.9"
+#define PYO_VERSION "0.7.0"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -106,6 +106,7 @@
 #define MYATAN2 atan2f
 #define MYEXP expf
 #define MYROUND roundf
+#define MYTANH tanhf
 
 #else
 #define LIB_BASE_NAME "_pyo64"
@@ -187,7 +188,7 @@
 #define MYATAN2 atan2
 #define MYEXP exp
 #define MYROUND round
-
+#define MYTANH tanh
 
 #endif
 #endif
@@ -411,6 +412,7 @@ extern PyTypeObject M_Atan2Type;
 extern PyTypeObject M_FloorType;
 extern PyTypeObject M_CeilType;
 extern PyTypeObject M_RoundType;
+extern PyTypeObject M_TanhType;
 extern PyTypeObject FFTMainType;
 extern PyTypeObject FFTType;
 extern PyTypeObject IFFTType;
@@ -586,11 +588,8 @@ extern PyTypeObject Pointer2Type;
 /* INIT INPUT STREAM */
 #define INIT_INPUT_STREAM \
     if ( PyObject_HasAttrString((PyObject *)inputtmp, "server") == 0 ) { \
-        PySys_WriteStderr("TypeError: \"input\" argument must be a PyoObject.\n"); \
-        if (PyInt_AsLong(PyObject_CallMethod(self->server, "getIsBooted", NULL))) { \
-            PyObject_CallMethod(self->server, "shutdown", NULL); \
-        } \
-        Py_Exit(1); \
+        PyErr_SetString(PyExc_TypeError, "\"input\" argument must be a PyoObject.\n"); \
+        Py_RETURN_NONE; \
     } \
     Py_INCREF(inputtmp); \
     Py_XDECREF(self->input); \
@@ -728,21 +727,44 @@ extern PyTypeObject Pointer2Type;
     return samples;
 
 #define GET_VIEW_TABLE \
-    int i, y; \
-    int w = 500; \
-    int h = 200; \
-    int h2 = h/2; \
-    int amp = h2 - 2; \
-    float step = (float)self->size / (float)(w); \
-    PyObject *samples; \
+    int i, y, w, h, h2, amp; \
+    float step; \
+    PyObject *samples, *tuple, *sizetmp = NULL; \
  \
-    samples = PyList_New(w*4); \
+    static char *kwlist[] = {"size", NULL}; \
+ \
+    if (! PyArg_ParseTupleAndKeywords(args, kwds, "O", kwlist, &sizetmp)) \
+        return PyInt_FromLong(-1); \
+ \
+    if (sizetmp) { \
+        if (PyTuple_Check(sizetmp)) { \
+            w = PyInt_AsLong(PyTuple_GET_ITEM(sizetmp, 0)); \
+            h = PyInt_AsLong(PyTuple_GET_ITEM(sizetmp, 1)); \
+        } \
+        else if (PyList_Check(sizetmp)) { \
+            w = PyInt_AsLong(PyList_GET_ITEM(sizetmp, 0)); \
+            h = PyInt_AsLong(PyList_GET_ITEM(sizetmp, 1)); \
+        } \
+        else { \
+            w = 500; \
+            h = 200; \
+        } \
+    } \
+    else { \
+        w = 500; \
+        h = 200; \
+    } \
+    h2 = h/2; \
+    amp = h2 - 2; \
+    step = (float)self->size / (float)(w); \
+ \
+    samples = PyList_New(w); \
     for(i=0; i<w; i++) { \
-        y = self->data[(int)(i*step)] * amp + amp; \
-        PyList_SetItem(samples, i*4, PyInt_FromLong(i)); \
-        PyList_SetItem(samples, i*4+1, PyInt_FromLong(h-y)); \
-        PyList_SetItem(samples, i*4+2, PyInt_FromLong(i)); \
-        PyList_SetItem(samples, i*4+3, PyInt_FromLong(h-y)); \
+        y = self->data[(int)(i*step)] * amp + amp + 2; \
+        tuple = PyTuple_New(2); \
+        PyTuple_SetItem(tuple, 0, PyInt_FromLong(i)); \
+        PyTuple_SetItem(tuple, 1, PyInt_FromLong(h-y)); \
+        PyList_SetItem(samples, i, tuple); \
     } \
  \
     return samples;
