@@ -20,6 +20,7 @@ along with pyo.  If not, see <http://www.gnu.org/licenses/>.
 """
 from types import ListType, FloatType, IntType
 import math, sys, os, random
+import __builtin__
 
 try:
     from PIL import Image, ImageDraw, ImageTk
@@ -37,19 +38,30 @@ try:
 except:
     PYO_USE_WX = False
 
+if hasattr(__builtin__, 'EPYO_APP_OPENED'):
+    PYO_USE_WX = True
+
+PYO_USE_TK = False
 if not PYO_USE_WX:
     try:
         from Tkinter import *
         from _tkwidgets import *
+        PYO_USE_TK = True
+        print """
+WxPython is not found for the current python version. 
+Pyo will use a minimal GUI toolkit written with Tkinter. 
+This toolkit has limited functionnalities and is no more 
+maintained or updated. If you want to use all of pyo's
+GUI features, you should install WxPython, available here: 
+http://www.wxpython.org/
+"""
     except:
-        if sys.platform == "linux2":
-            response = raw_input("""python-tk package is missing! It is needed to use pyo graphical interfaces.
-Do you want to install it? (yes/no): """)
-            if response == 'yes':
-                os.system('sudo apt-get install python-tk')
-        else:
-            print "Tkinter is missing! It is needed to use pyo graphical interfaces. Please install it!"
-        sys.exit()
+        PYO_USE_TK = False
+        print """
+Neither WxPython nor Tkinter are found for the current python version.
+Pyo's GUI features are disabled. For a complete GUI toolkit, you should 
+consider installing WxPython, available here: http://www.wxpython.org/
+"""
 
 X, Y, CURRENT_X, MAX_X, NEXT_Y = 800, 700, 30, 30, 30
 WINDOWS = []
@@ -60,8 +72,10 @@ TABLEWINDOWS = []
 SNDTABLEWINDOWS = []
 MATRIXWINDOWS = []
 SPECTRUMWINDOWS = []
+WX_APP = False
 
 def createRootWindow():
+    global WX_APP
     if not PYO_USE_WX:
         if len(WINDOWS) == 0:
             root = Tk()
@@ -70,8 +84,9 @@ def createRootWindow():
         else:
             return None
     else:        
-        if wx.GetApp() == None: 
-            win = wx.App(False) 
+        if not WX_APP: 
+            win = wx.App(False)
+            WX_APP = True 
             return win
         else:
             return None
@@ -142,8 +157,7 @@ def wxCreateDelayedTableWindows():
     global CURRENT_X, MAX_X, NEXT_Y
     for win in TABLEWINDOWS:
         object = win[3]
-        if WITH_PIL: f = ViewTable_withPIL(None, win[0], win[1], object)
-        else: f = ViewTable_withoutPIL(None, win[0], win[1], object)
+        f = ViewTable(None, win[0], win[1], object)
         if object != None:
             object._setViewFrame(f)
         wxDisplayWindow(f, win[2])
@@ -183,7 +197,7 @@ def createCtrlWindow(obj, map_list, title, wxnoserver=False):
         if title == None: title = obj.__class__.__name__
         win.title(title)
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
             f = PyoObjectControl(None, obj, map_list)
             if title == None: title = obj.__class__.__name__
@@ -195,7 +209,7 @@ def createGraphWindow(obj, mode, xlen, yrange, title, wxnoserver=False):
     if not PYO_USE_WX:
         print "WxPython must be installed to use the 'graph()' method."
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
             f = TableGrapher(None, obj, mode, xlen, yrange)
             if title == None: title = obj.__class__.__name__
@@ -207,7 +221,7 @@ def createDataGraphWindow(obj, yrange, title, wxnoserver=False):
     if not PYO_USE_WX:
         print "WxPython must be installed to use the 'graph()' method."
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
             f = DataTableGrapher(None, obj, yrange)
             if title == None: title = obj.__class__.__name__
@@ -224,10 +238,9 @@ def createViewTableWindow(samples, title="Table waveform", wxnoserver=False, tab
         win.resizable(False, False)
         win.title(title)
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
-            if WITH_PIL: f = ViewTable_withPIL(None, samples, tableclass, object)
-            else: f = ViewTable_withoutPIL(None, samples, tableclass, object)
+            f = ViewTable(None, samples, tableclass, object)
             wxShowWindow(f, title, root)
             if object != None:
                 object._setViewFrame(f)
@@ -243,7 +256,7 @@ def createSndViewTableWindow(obj, title="Table waveform", wxnoserver=False, tabl
         win.resizable(False, False)
         win.title(title)
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
             f = SndViewTable(None, obj, tableclass, mouse_callback)
             if title == None: title = obj.__class__.__name__
@@ -263,7 +276,7 @@ It helps a lot to speed up matrix drawing!"""
         win.resizable(False, False)
         win.title(title)
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
             if WITH_PIL: f = ViewMatrix_withPIL(None, samples, size, object)
             else: f = ViewMatrix_withoutPIL(None, samples, size, object)
@@ -277,7 +290,7 @@ def createSpectrumWindow(object, title, wxnoserver=False):
     if not PYO_USE_WX:
         print "WxPython must be installed to use the Spectrum display."
     else:
-        if wxnoserver or wx.GetApp() != None:
+        if wxnoserver or WX_APP:
             root = createRootWindow()
             f = SpectrumDisplay(None, object)
             if title == None: title = object.__class__.__name__
@@ -287,7 +300,7 @@ def createSpectrumWindow(object, title, wxnoserver=False):
         else:
             SPECTRUMWINDOWS.append([object, title])   
         
-def createServerGUI(nchnls, start, stop, recstart, recstop, setAmp, started, locals, shutdown, meter, timer, amp):
+def createServerGUI(nchnls, start, stop, recstart, recstop, setAmp, started, locals, shutdown, meter, timer, amp, exit):
     global X, Y, MAX_X, NEXT_Y
     if not PYO_USE_WX:
         createRootWindow()
@@ -297,7 +310,7 @@ def createServerGUI(nchnls, start, stop, recstart, recstop, setAmp, started, loc
         f.focus_set()
     else:
         win = createRootWindow()
-        f = ServerGUI(None, nchnls, start, stop, recstart, recstop, setAmp, started, locals, shutdown, meter, timer, amp) 
+        f = ServerGUI(None, nchnls, start, stop, recstart, recstop, setAmp, started, locals, shutdown, meter, timer, amp, exit) 
         f.SetTitle("pyo server")
         f.SetPosition((30, 30))
         f.Show()
