@@ -511,6 +511,8 @@ class Compress(PyoObject):
                           SLMap(1., 10., 'lin', 'ratio',  self._ratio),
                           SLMap(0.001, .3, 'lin', 'risetime',  self._risetime),
                           SLMap(0.001, .3, 'lin', 'falltime',  self._falltime),
+                          SLMap(0, 25, 'lin', 'lookahead',  self._lookahead, dataOnly=True),
+                          SLMap(0, 1, 'lin', 'knee',  self._knee, dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
@@ -690,6 +692,7 @@ class Gate(PyoObject):
         self._map_list = [SLMap(-100., 0., 'lin', 'thresh',  self._thresh),
                           SLMap(0.0001, .3, 'lin', 'risetime',  self._risetime),
                           SLMap(0.0001, .3, 'lin', 'falltime',  self._falltime),
+                          SLMap(0, 25, 'lin', 'lookahead',  self._lookahead, dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
