@@ -140,7 +140,7 @@ class Server(object):
         self._globalseed = 0
         self._server.__init__(sr, nchnls, buffersize, duplex, audio, jackname)
 
-    def gui(self, locals=None, meter=True, timer=True):
+    def gui(self, locals=None, meter=True, timer=True, exit=True):
         """
         Show the server's user interface.
         
@@ -155,10 +155,14 @@ class Server(object):
             timer : boolean, optional
                 If True, the interface will show a clock of the current time.
                 Defaults to True.
+            exit : boolean, optional
+                If True, the python interpreter will exit when the 'Quit' button is pressed,
+                Otherwise, the GUI will be closed leaving the interpreter alive.
+                Defaults to True.
             
         """
         f, win = createServerGUI(self._nchnls, self.start, self.stop, self.recstart, self.recstop,
-                                 self.setAmp, self.getIsStarted(), locals, self.shutdown, meter, timer, self._amp)
+                                 self.setAmp, self.getIsStarted(), locals, self.shutdown, meter, timer, self._amp, exit)
         if meter:
             self._server.setAmpCallable(f)
         if timer:
@@ -349,7 +353,7 @@ class Server(object):
 
     def setJackAuto(self, xin=True, xout=True):
         """
-        Tells the server to auto-connect (or not) Jack ports.
+        Tells the server to auto-connect (or not) Jack ports to System ports.
         
         :Args:
 
@@ -361,6 +365,32 @@ class Server(object):
         """        
         self._server.setJackAuto(xin, xout)
 
+    def setJackAutoConnectInputPorts(self, ports):
+        """
+        Tells the server to auto-connect Jack input ports to pre-defined Jack ports.
+        
+        :Args:
+
+            ports : string or list of strings
+                Name of the Jack port(s) to auto-connect. Regular Expressions are allowed.
+
+        """
+        ports, lmax = convertArgsToLists(ports)
+        self._server.setJackAutoConnectInputPorts(ports)
+
+    def setJackAutoConnectOutputPorts(self, ports):
+        """
+        Tells the server to auto-connect Jack output ports to pre-defined Jack ports.
+        
+        :Args:
+
+            ports : string or list of strings
+                Name of the Jack port(s) to auto-connect. Regular Expressions are allowed.
+
+        """
+        ports, lmax = convertArgsToLists(ports)
+        self._server.setJackAutoConnectOutputPorts(ports)
+        
     def setGlobalSeed(self, x):
         """
         Set the server's global seed used by random objects.
