@@ -136,6 +136,7 @@ class Osc(PyoObject):
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = [SLMapFreq(self._freq),
                           SLMapPhase(self._phase),
+                          SLMap(1, 4, 'lin', 'interp', self._interp, res="int", dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
@@ -403,6 +404,7 @@ class OscTrig(PyoObject):
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = [SLMapFreq(self._freq),
                           SLMapPhase(self._phase),
+                          SLMap(1, 4, 'lin', 'interp', self._interp, res="int", dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
@@ -854,7 +856,10 @@ class TableRead(PyoObject):
 
 
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
-        self._map_list = [SLMapFreq(self._freq), SLMapMul(self._mul)]
+        self._map_list = [SLMap(0.0001, 1000, 'log', 'freq', self._freq), 
+                          SLMap(0, 1, 'lin', 'loop', self._loop, res="int", dataOnly=True),
+                          SLMap(1, 4, 'lin', 'interp', self._interp, res="int", dataOnly=True),
+                          SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
     @property
@@ -1019,7 +1024,11 @@ class Pulsar(PyoObject):
         :Args:
 
             x : int {1, 2, 3, 4}
-                new `interp` attribute.
+                Choice of the interpolation method.
+                    1. no interpolation
+                    2. linear
+                    3. cosinus
+                    4. cubic
         
         """
         self._interp = x
@@ -1030,6 +1039,7 @@ class Pulsar(PyoObject):
         self._map_list = [SLMapFreq(self._freq),
                           SLMap(0., 1., 'lin', 'frac', self._frac),
                           SLMapPhase(self._phase),
+                          SLMap(1, 4, 'lin', 'interp', self._interp, res="int", dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
@@ -1149,6 +1159,144 @@ class Pointer(PyoObject):
     @index.setter
     def index(self, x): self.setIndex(x)
 
+class Pointer2(PyoObject):
+    """
+    High quality table reader with control on the pointer position.
+
+    :Parent: :py:class:`PyoObject`
+
+    :Args:
+
+        table : PyoTableObject
+            Table containing the waveform samples.
+        index : PyoObject
+            Normalized position in the table between 0 and 1.
+        interp : int {1, 2, 3, 4}, optional
+            Choice of the interpolation method. Defaults to 4.
+                1. no interpolation
+                2. linear
+                3. cosinus
+                4. cubic
+        autosmooth : boolean, optional
+            If True, a lowpass filter, following the pitch, is applied on 
+            
+            the output signal to reduce the quantization noise produced 
+            
+            by very low transpositions. Defaults to True.
+
+    >>> s = Server().boot()
+    >>> s.start()
+    >>> t = SndTable(SNDS_PATH + '/transparent.aif')
+    >>> freq = t.getRate()
+    >>> p = Phasor(freq=[freq*0.5, freq*0.45])
+    >>> a = Pointer2(table=t, index=p, mul=.3).out()
+
+    """
+    def __init__(self, table, index, interp=4, autosmooth=True, mul=1, add=0):
+        PyoObject.__init__(self, mul, add)
+        self._table = table
+        self._index = index
+        self._interp = interp
+        self._autosmooth = autosmooth
+        table, index, interp, autosmooth, mul, add, lmax = convertArgsToLists(table, index, interp, autosmooth, mul, add)
+        self._base_objs = [Pointer2_base(wrap(table,i), wrap(index,i), wrap(interp,i), wrap(autosmooth,i), wrap(mul,i), wrap(add,i)) for i in range(lmax)]
+
+    def setTable(self, x):
+        """
+        Replace the `table` attribute.
+        
+        :Args:
+
+            x : PyoTableObject
+                new `table` attribute.
+        
+        """
+        self._table = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setTable(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setIndex(self, x):
+        """
+        Replace the `index` attribute.
+        
+        :Args:
+
+            x : PyoObject
+                new `index` attribute.
+        
+        """
+        self._index = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setIndex(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setInterp(self, x):
+        """
+        Replace the `interp` attribute.
+        
+        :Args:
+
+            x : int {1, 2, 3, 4}
+                new `interp` attribute.
+                    1. no interpolation
+                    2. linear interpolation
+                    3. cosine interpolation
+                    4. cubic interpolation (default)
+        
+        """
+        self._interp = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setInterp(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def setAutoSmooth(self, x):
+        """
+        Replace the `autosmooth` attribute.
+        
+        If True, a lowpass filter, following the playback speed, is applied on 
+        the output signal to reduce the quantization noise produced by very 
+        low transpositions.
+        
+        :Args:
+
+            x : boolean
+                new `autosmooth` attribute.
+        
+        """
+        self._autosmooth = x
+        x, lmax = convertArgsToLists(x)
+        [obj.setAutoSmooth(wrap(x,i)) for i, obj in enumerate(self._base_objs)]
+
+    def ctrl(self, map_list=None, title=None, wxnoserver=False):
+        self._map_list = [SLMapMul(self._mul)]
+        PyoObject.ctrl(self, map_list, title, wxnoserver)
+
+    @property
+    def table(self):
+        """PyoTableObject. Table containing the waveform samples.""" 
+        return self._table
+    @table.setter
+    def table(self, x): self.setTable(x)
+
+    @property
+    def index(self):
+        """PyoObject. Index pointer position in the table.""" 
+        return self._index
+    @index.setter
+    def index(self, x): self.setIndex(x)
+
+    @property
+    def interp(self): 
+        """int {1, 2, 3, 4}. Interpolation method."""
+        return self._interp
+    @interp.setter
+    def interp(self, x): self.setInterp(x)
+
+    @property
+    def autosmooth(self): 
+        """boolean. Quantization noise filter."""
+        return self._autosmooth
+    @autosmooth.setter
+    def autosmooth(self, x): self.setAutoSmooth(x)
+
 class TableIndex(PyoObject):
     """
     Table reader by sample position without interpolation.
@@ -1710,6 +1858,8 @@ class Granulator(PyoObject):
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = [SLMap(0.1, 2., 'lin', 'pitch', self._pitch),
                           SLMap(0.01, 1., 'lin', 'dur', self._dur),
+                          SLMap(1, 256, 'lin', 'grains', self._grains, res="int", dataOnly=True),
+                          SLMap(0.001, 1, 'log', 'basedur', self._basedur, dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
@@ -2128,7 +2278,9 @@ class Looper(PyoObject):
     def ctrl(self, map_list=None, title=None, wxnoserver=False):
         self._map_list = [SLMap(0.1, 2., 'lin', 'pitch', self._pitch),
                           SLMap(0., self._table.getDur(), 'lin', 'start', self._start),
-                          SLMap(0.01, 1., 'lin', 'dur', self._dur),
+                          SLMap(0.01, self._table.getDur(), 'lin', 'dur', self._dur),
+                          SLMap(0, 2, 'lin', 'xfadeshape', self._xfadeshape, res="int", dataOnly=True),
+                          SLMap(1, 4, 'lin', 'interp', self._interp, res="int", dataOnly=True),
                           SLMapMul(self._mul)]
         PyoObject.ctrl(self, map_list, title, wxnoserver)
 
