@@ -169,11 +169,8 @@ InputFader_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
         Py_RETURN_NONE; 
 
     if ( PyObject_HasAttrString((PyObject *)inputtmp, "server") == 0 ) {
-        PySys_WriteStderr("TypeError: \"input\" argument must be a PyoObject.\n");
-        if (PyInt_AsLong(PyObject_CallMethod(self->server, "getIsBooted", NULL))) {
-            PyObject_CallMethod(self->server, "shutdown", NULL);
-        }
-        Py_Exit(1);
+        PyErr_SetString(PyExc_TypeError, "\"input\" argument must be a PyoObject.\n");
+        Py_RETURN_NONE;
     }
     Py_INCREF(inputtmp);
     Py_XDECREF(self->input1);
