@@ -333,9 +333,9 @@ typedef struct {
     pyo_audio_HEAD
     PyObject *value;
     Stream *value_stream;
-    MYFLT time;
     MYFLT lastValue;
     MYFLT currentValue;
+    MYFLT time;
     long timeStep;
     MYFLT stepVal;
     long timeCount;
@@ -346,20 +346,19 @@ static void
 SigTo_generates_i(SigTo *self) {
     int i;
     MYFLT value;
-    
     if (self->modebuffer[2] == 0) {
         value = PyFloat_AS_DOUBLE(self->value);
+        if (value != self->lastValue) {
+            self->timeCount = 0;
+            self->timeStep = (long)(self->time * self->sr);
+            self->stepVal = (value - self->currentValue) / self->timeStep;
+            self->lastValue = value;
+        }
         if (self->timeStep <= 0) {
             for (i=0; i<self->bufsize; i++)
                 self->data[i] = self->currentValue = self->lastValue = value;
         }
-        else {
-            if (value != self->lastValue) {
-                self->timeCount = 0;
-                self->stepVal = (value - self->currentValue) / self->timeStep;
-                self->lastValue = value;
-            }    
-        
+        else {        
             for (i=0; i<self->bufsize; i++) {
                 if (self->timeCount == (self->timeStep - 1)) {
                     self->currentValue = value;
@@ -386,6 +385,7 @@ SigTo_generates_i(SigTo *self) {
                 value = vals[i];
                 if (value != self->lastValue) {
                     self->timeCount = 0;
+                    self->timeStep = (long)(self->time * self->sr);
                     self->stepVal = (value - self->currentValue) / self->timeStep;
                     self->lastValue = value;
                 }    
@@ -497,7 +497,6 @@ SigTo_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
 
     self->value = PyFloat_FromDouble(0.0);
     self->time = 0.025;
-    self->timeStep = (long)(self->time * self->sr);
     self->timeCount = 0;
     self->stepVal = 0.0;
 	self->modebuffer[0] = 0;
@@ -532,6 +531,7 @@ SigTo_new(PyTypeObject *type, PyObject *args, PyObject *kwds)
     PyObject_CallMethod(self->server, "addStream", "O", self->stream);
     
     self->lastValue = self->currentValue = inittmp;
+    self->timeStep = (long)(self->time * self->sr);
     
     (*self->mode_func_ptr)(self);
 
@@ -590,7 +590,6 @@ SigTo_setTime(SigTo *self, PyObject *arg)
 	Py_INCREF(tmp);
 	if (isNumber == 1) {
 		self->time = PyFloat_AS_DOUBLE(PyNumber_Float(tmp));
-        self->timeStep = (long)(self->time * self->sr);
 	}
     
 	Py_INCREF(Py_None);
@@ -992,6 +991,26 @@ VarPort_setTime(VarPort *self, PyObject *arg)
 	return Py_None;
 }	
 
+static PyObject *
+VarPort_setFunction(VarPort *self, PyObject *arg)
+{
+	PyObject *tmp;
+	
+	if (! PyCallable_Check(arg)) {
+        PyErr_SetString(PyExc_TypeError, "The function attribute must be callable.");
+		Py_INCREF(Py_None);
+		return Py_None;
+	}
+    
+    tmp = arg;
+    Py_XDECREF(self->callable);
+    Py_INCREF(tmp);
+    self->callable = tmp;
+  
+	Py_INCREF(Py_None);
+	return Py_None;
+}	
+
 static PyObject * VarPort_getServer(VarPort* self) { GET_SERVER };
 static PyObject * VarPort_getStream(VarPort* self) { GET_STREAM };
 static PyObject * VarPort_setMul(VarPort *self, PyObject *arg) { SET_MUL };	
@@ -1026,6 +1045,7 @@ static PyMethodDef VarPort_methods[] = {
     {"stop", (PyCFunction)VarPort_stop, METH_NOARGS, "Stops computing."},
     {"setValue", (PyCFunction)VarPort_setValue, METH_O, "Sets VarPort value."},
     {"setTime", (PyCFunction)VarPort_setTime, METH_O, "Sets ramp time in seconds."},
+    {"setFunction", (PyCFunction)VarPort_setFunction, METH_O, "Sets function to be called."},
     {"setMul", (PyCFunction)VarPort_setMul, METH_O, "Sets VarPort mul factor."},
     {"setAdd", (PyCFunction)VarPort_setAdd, METH_O, "Sets VarPort add factor."},
     {"setSub", (PyCFunction)VarPort_setSub, METH_O, "Sets inverse add factor."},
